==> necroplayer_0.2.0.orig.tar.gz: necroplayer-0.2.0.orig/src/Engine.cpp <==
#include <iostream>
#include <QtGui>

#include "UPlay.h"

Engine::Engine(UPlay* parent)
{
	this->parent = parent;
	
	// Phonon init
	audioOutput = new Phonon::AudioOutput(Phonon::MusicCategory);
	mediaObject = new Phonon::MediaObject();	

	seekSlider = new Phonon::SeekSlider();
	Phonon::createPath(mediaObject,audioOutput);

        
	seekSlider->setIconVisible(false);
	seekLayout = new QVBoxLayout;
	timeLayout = new QHBoxLayout;
	currentTime = new QLabel("0:00");
	totalTime = new QLabel(" / 0:00");
	//seekLayout->addWidget(seekSlider);
	timeLayout->addWidget(currentTime);
	timeLayout->addWidget(totalTime);
	timeLayout->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
	seekLayout->addLayout(timeLayout);
	seekLayout->addWidget(seekSlider);

	volLayout=new QVBoxLayout;

	volumeSlider = new Phonon::VolumeSlider();
	volumeSlider->setAudioOutput(audioOutput);
	volumeSlider->setSizePolicy(QSizePolicy::Maximum,QSizePolicy::Expanding);
	volumeSlider->setOrientation(Qt::Vertical);
	//volumeSlider->setMuteVisible(false);
	volLayout->addWidget(volumeSlider);
	volLayout->setSpacing(0);

	
	// meta tag resolver
	mediaObjectForMetaInfos = new Phonon::MediaObject();
	connect(mediaObjectForMetaInfos, SIGNAL(stateChanged(Phonon::State, Phonon::State)),
				this, SLOT(metaInfosUpdated(Phonon::State, Phonon::State)));

	// media
	connect(mediaObject,SIGNAL(finished()),SLOT(playEnded()));
	connect(mediaObject,SIGNAL(tick(qint64)),SLOT(refreshPlayedTime()));
	
	connect(mediaObject, SIGNAL(stateChanged(Phonon::State, Phonon::State)),
				    this, SLOT(currentInfosUpdated(Phonon::State, Phonon::State)));

	listMedias.clear();
	
	// default value
	currentPlayedMedia = -1;
	lastUpdated = -1;
}

Engine::~Engine()
{	
	//qDebug()<<"Engine destructor";
	if (volumeSlider)
		delete volumeSlider;
	if (volLayout)
		delete volLayout;
	if (audioOutput)
		delete audioOutput; audioOutput = NULL;
	if (mediaObject)
		delete mediaObject; mediaObject = NULL;
	if (seekSlider)
		delete seekSlider; seekSlider = NULL;
	if (currentTime)
		delete currentTime; currentTime = NULL;
	if (totalTime)
		delete totalTime; totalTime = NULL;
	if (mediaObjectForMetaInfos)
		delete mediaObjectForMetaInfos; mediaObjectForMetaInfos = NULL;
	if (timeLayout)
		delete timeLayout;
	if (seekLayout)
		delete seekLayout; seekLayout = NULL;

}

void
Engine::stop()
{
	// stop playing
	if (mediaObject)
	{
		mediaObject->stop();

		parent->ui->getPlaylist().setBold(currentPlayedMedia,false);
		currentPlayedMedia = -1;
		parent->ui->getControls().setPlayIcon(Phonon::PlayingState);
		parent->ui->setInfos("\n");
		currentTime->setText("0:00");
		totalTime->setText(" / 0:00");
		parent->ui->setWindowTitle("NecroPlayer");
	}
}

/**
 * Return the row played, or -1 if an error occured
 */
int
Engine::play(int row)
{
  	if (currentPlayedMedia != -1 && row == -1)
	{
		switch (mediaObject->state())
		{	
			case Phonon::PausedState:
				row = currentPlayedMedia;
				if (mediaObject)
				{
					mediaObject->play();
					parent->ui->getControls().setPlayIcon(Phonon::PausedState);
				}
				break;
			case Phonon::PlayingState:
				mediaObject->pause();
				parent->ui->getControls().setPlayIcon(Phonon::PlayingState);
				break;
			default:
				break;
		}
	}
	else
	{

		if (row < listMedias.count())
		{

			// preparing reading
			mediaObject->setCurrentSource(listSources[row]);
			mediaObject->setTickInterval(1000);
			mediaObject->setTransitionTime(1000);
			currentTime->setText("0:00");
			seekSlider->setMediaObject(mediaObject);

			if (currentPlayedMedia > -1)
			{
				parent->ui->getPlaylist().setBold(currentPlayedMedia,false);
			}
			currentPlayedMedia = row;
			parent->ui->getPlaylist().setBold(row,true);

			// go
			mediaObject->play();
			
			//totalTime->setText(" / 0:00");
			parent->ui->getControls().setPlayIcon(Phonon::PausedState);

		}
		else
		{
			row = -1;
		}
	}

	return row;
}

void Engine::addMedia(QStringList files)
{
	if (files.isEmpty())
         return;
	
	//int index = listSources.size();
	QFileInfo fi;
	Media tmp_media;
	 
	foreach (QString string, files) 
	{
	  Phonon::MediaSource source(string);
	  listSources.append(source);
	  listUris.append(string); 
	  fi.setFile(string);
	  parent->ui->addItem(fi.fileName());
	  tmp_media.title=fi.fileName();
	  tmp_media.artist="";
	  tmp_media.album="";
	  listMedias.append(tmp_media);
	  
	}
	
	if (!listSources.isEmpty())
	{
	 //  int index_cur = listSources.indexOf(mediaObjectForMetaInfos->currentSource());
	 // qDebug()<<"index_cur: "<<index_cur;
	 // qDebug()<<"index: "<<index;
	 // if (index_cur==index-1) //metaInfos not busy
	 //   mediaObjectForMetaInfos->setCurrentSource(listSources.at(index));
	}
}


void Engine::startMetaUpdater(bool reload)
{
  	if ((!listSources.isEmpty())&&(parent->config->useTags)&&(!parent->config->updateOnPlay))
	{
	  if(reload)
	  {
	    mediaObjectForMetaInfos->setCurrentSource(listSources.at(0));
	  }
	  else
	  {
	    int index_cur = listSources.indexOf(mediaObjectForMetaInfos->currentSource());
	    if(index_cur==lastUpdated)
	    {
	      mediaObjectForMetaInfos->setCurrentSource(listSources.at(lastUpdated+1));
	    }
	  }
	}
  
}

void
Engine::refreshPlayedTime()
{
	currentTime->setText(Engine::msToString(mediaObject->currentTime()));
//	totalTime->setText(" / " + Engine::msToString(mediaObject->totalTime()));
	
}

Media
Engine::getInfos(unsigned int row)
{
	Media media;
	if (row < (unsigned int)listMedias.count())
	{
		media = listMedias.at(row);
	}
	return media;
}

QString
Engine::getUri(unsigned int row)
{
	QString ret = "";
	if (row < (unsigned int)listUris.count())
	{
		ret = listUris.at(row);
	}
	return ret;
}

void
Engine::metaInfosUpdated(Phonon::State newState, Phonon::State oldState)
{
	// When a file was added, and when
	// his metadata were resolved, we can add it to the displayed playlist
	
	 if (newState != Phonon::StoppedState && newState != Phonon::PausedState) //
	  return;
	 
	 if (mediaObjectForMetaInfos->currentSource().type() == Phonon::MediaSource::Invalid)
          return;
	
	 //mediaObjectForMetaInfos
	  QMap<QString, QString> metaData = mediaObjectForMetaInfos->metaData();

	Media media;
		// get infos
	media.title = metaData.value("TITLE");
	if (media.title == "")
	{
	  int nn=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
	  QFileInfo fi(listUris[nn]);
	  media.title = fi.fileName();
	}
	media.artist = metaData.value("ARTIST");
	media.album = metaData.value("ALBUM");
	media.totalTime = Engine::msToString(mediaObjectForMetaInfos->totalTime());
	
	QString result;
	if(media.artist == "")
	  result = media.title;
	else
	  result = media.artist + " - " + media.title;
	
	parent->ui->changeItem(result, listSources.indexOf(mediaObjectForMetaInfos->currentSource()));
	listMedias.replace(listSources.indexOf(mediaObjectForMetaInfos->currentSource()),media);
	//parent->ui->addItem(result);
	//listMedias.append(media);
	lastUpdated=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
	int index = listSources.indexOf(mediaObjectForMetaInfos->currentSource()) + 1;
	if (listSources.size() > index) 
	{
	  mediaObjectForMetaInfos->setCurrentSource(listSources.at(index));
	}

}

void Engine::currentInfosUpdated(Phonon::State newState, Phonon::State oldState)
{
   //qDebug()<<"=======>oldState: "<<oldState;
   //qDebug()<<"=======>newState: "<<newState;
  if (newState == Phonon::PlayingState )
  {
    totalTime->setText(" / " + Engine::msToString(mediaObject->totalTime()));
  
  
  //bool updateMetaOnPlay=true;
  
    if ((parent->config->useTags)&&(parent->config->updateOnPlay))
    {
      if (mediaObject->currentSource().type() != Phonon::MediaSource::Invalid)
      {
	  QMap<QString, QString> metaData = mediaObject->metaData();
	  Media media;
	
	  media.title = metaData.value("TITLE");
	  media.artist = metaData.value("ARTIST");
	  media.album = metaData.value("ALBUM");
	  media.totalTime = Engine::msToString(mediaObject->totalTime());
	
	  if(media.title!="")
	  {
	    QString result;
	    result = media.artist + " - " + media.title;
	    parent->ui->changeItem(result, currentPlayedMedia);
	    listMedias.replace(currentPlayedMedia,media);
	    //qDebug()<<currentPlayedMedia;
	    //qDebug()<<listSources.indexOf(mediaObject->currentSource());
	  
	  }
      }        
    }
  
  
    // Get infos
    Media media = getInfos(currentPlayedMedia);

    QString s;

    if (media.artist.isEmpty())
    {
      s = media.title + "\n";
      parent->ui->setWindowTitle(media.title);
    }
    else
    {
      s = media.artist + "\n" + media.title;
      parent->ui->setWindowTitle(media.artist+" - "+ media.title);
    }

    parent->ui->setInfos(s);
    
  }
  
  
  //mediaObject
  
}

void
Engine::playEnded()
{
	parent->next();
}

int
Engine::delMedia(int row)
{
	int ret = 0;
	if (row < listMedias.count())
	{
		listMedias.remove(row);
		listSources.remove(row);
		listUris.remove(row);
		ret = 1;
	}
	return ret;
}

void
Engine::clearPlayList()
{
	if (parent && parent->ui)
		parent->ui->clearPlaylist();
	listMedias.clear();
	listSources.clear();
	listUris.clear();
}

QString
Engine::msToString(qint64 ms)
{
	QString ret = "";
	qint64 tmp = ms / 1000;
	int seconds = 0;
	int minutes = 0;
	int hours = 0;
	int tmpMins = tmp/60;
	if (tmpMins > 59)
	{
		hours = tmpMins/60;
		minutes = tmpMins%60;		
	}
	else
	{
		minutes = tmpMins;
	}
	seconds = tmp%60;

	if (hours > 0)
	{ // with hours
		/**
		 * We test if minutes/10 == 0 
		 * to not have a display like this -> 1:5:12
		 * but a display like this -> 1:05:12
		 */
		ret += QString::number(hours) + ":";
		if (minutes/10 == 0)
		{
			ret += "0";
		}
		ret += QString::number(minutes) + ":";
		if (seconds/10 == 0)
		{
			ret += "0";
		}
		ret += QString::number(seconds);
	}
	else
	{ // without hours
		ret += QString::number(minutes) + ":";
		if (seconds/10 == 0)
		{
			ret += "0";
		}
		ret += QString::number(seconds);
	}
	return ret;
}

==> necroplayer_0.2.1.orig.tar.gz: necroplayer-0.2.1.orig/src/Engine.cpp <==
#include <iostream>
#include <QtGui>

#include "UPlay.h"

Engine::Engine(UPlay* parent)
{
	this->parent = parent;
	
	// Phonon init
	audioOutput = new Phonon::AudioOutput(Phonon::MusicCategory);
	mediaObject = new Phonon::MediaObject();	

	seekSlider = new Phonon::SeekSlider();
	Phonon::createPath(mediaObject,audioOutput);

        
	seekSlider->setIconVisible(false);
	seekLayout = new QVBoxLayout;
	timeLayout = new QHBoxLayout;
	currentTime = new QLabel("0:00");
	totalTime = new QLabel(" / 0:00");
	//seekLayout->addWidget(seekSlider);
	timeLayout->addWidget(currentTime);
	timeLayout->addWidget(totalTime);
	timeLayout->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
	seekLayout->addLayout(timeLayout);
	seekLayout->addWidget(seekSlider);

	volLayout=new QVBoxLayout;

	volumeSlider = new Phonon::VolumeSlider();
	volumeSlider->setAudioOutput(audioOutput);
	volumeSlider->setSizePolicy(QSizePolicy::Maximum,QSizePolicy::Expanding);
	volumeSlider->setOrientation(Qt::Vertical);
	//volumeSlider->setMuteVisible(false);
	volLayout->addWidget(volumeSlider);
	volLayout->setSpacing(0);

	
	// meta tag resolver
	mediaObjectForMetaInfos = new Phonon::MediaObject();
	connect(mediaObjectForMetaInfos, SIGNAL(stateChanged(Phonon::State, Phonon::State)),
				this, SLOT(metaInfosUpdated(Phonon::State, Phonon::State)));

	// media
	connect(mediaObject,SIGNAL(finished()),SLOT(playEnded()));
	connect(mediaObject,SIGNAL(tick(qint64)),SLOT(refreshPlayedTime()));
	
	connect(mediaObject, SIGNAL(stateChanged(Phonon::State, Phonon::State)),
				    this, SLOT(currentInfosUpdated(Phonon::State, Phonon::State)));

	listMedias.clear();
	
	// default value
	currentPlayedMedia = -1;
	lastUpdated = -1;
}

Engine::~Engine()
{	
	//qDebug()<<"Engine destructor";
	if (volumeSlider)
		delete volumeSlider;
	if (volLayout)
		delete volLayout;
	if (audioOutput)
		delete audioOutput; audioOutput = NULL;
	if (mediaObject)
		delete mediaObject; mediaObject = NULL;
	if (seekSlider)
		delete seekSlider; seekSlider = NULL;
	if (currentTime)
		delete currentTime; currentTime = NULL;
	if (totalTime)
		delete totalTime; totalTime = NULL;
	if (mediaObjectForMetaInfos)
		delete mediaObjectForMetaInfos; mediaObjectForMetaInfos = NULL;
	if (timeLayout)
		delete timeLayout;
	if (seekLayout)
		delete seekLayout; seekLayout = NULL;

}

void
Engine::stop()
{
	// stop playing
	if (mediaObject)
	{
		mediaObject->stop();

		parent->ui->getPlaylist().setBold(currentPlayedMedia,false);
		currentPlayedMedia = -1;
		parent->ui->getControls().setPlayIcon(Phonon::PlayingState);
		parent->ui->setInfos("\n");
		currentTime->setText("0:00");
		totalTime->setText(" / 0:00");
		parent->ui->setWindowTitle("NecroPlayer");
	}
}

/**
 * Return the row played, or -1 if an error occured
 */
int
Engine::play(int row)
{
  	if (currentPlayedMedia != -1 && row == -1)
	{
		switch (mediaObject->state())
		{	
			case Phonon::PausedState:
				row = currentPlayedMedia;
				if (mediaObject)
				{
					mediaObject->play();
					parent->ui->getControls().setPlayIcon(Phonon::PausedState);
				}
				break;
			case Phonon::PlayingState:
				mediaObject->pause();
				parent->ui->getControls().setPlayIcon(Phonon::PlayingState);
				break;
			default:
				break;
		}
	}
	else
	{

		if (row < listMedias.count())
		{

			// preparing reading
			mediaObject->setCurrentSource(listSources[row]);
			mediaObject->setTickInterval(1000);
			mediaObject->setTransitionTime(1000);
			currentTime->setText("0:00");
			seekSlider->setMediaObject(mediaObject);

			if (currentPlayedMedia > -1)
			{
				parent->ui->getPlaylist().setBold(currentPlayedMedia,false);
			}
			currentPlayedMedia = row;
			parent->ui->getPlaylist().setBold(row,true);

			// go
			mediaObject->play();
			
			//totalTime->setText(" / 0:00");
			parent->ui->getControls().setPlayIcon(Phonon::PausedState);

		}
		else
		{
			row = -1;
		}
	}

	return row;
}

void Engine::addMedia(QStringList files)
{
	if (files.isEmpty())
         return;
	
	//int index = listSources.size();
	QFileInfo fi;
	Media tmp_media;
	 
	foreach (QString string, files) 
	{
	  Phonon::MediaSource source(string);
	  listSources.append(source);
	  listUris.append(string); 
	  fi.setFile(string);
	  parent->ui->addItem(fi.fileName());
	  tmp_media.title=fi.fileName();
	  tmp_media.artist="";
	  tmp_media.album="";
	  listMedias.append(tmp_media);
	  
	}
	
	if (!listSources.isEmpty())
	{
	 //  int index_cur = listSources.indexOf(mediaObjectForMetaInfos->currentSource());
	 // qDebug()<<"index_cur: "<<index_cur;
	 // qDebug()<<"index: "<<index;
	 // if (index_cur==index-1) //metaInfos not busy
	 //   mediaObjectForMetaInfos->setCurrentSource(listSources.at(index));
	}
}


void Engine::startMetaUpdater(bool reload)
{
  	if ((!listSources.isEmpty())&&(parent->config->useTags)&&(!parent->config->updateOnPlay))
	{
	  if(reload)
	  {
	    mediaObjectForMetaInfos->setCurrentSource(listSources.at(0));
	  }
	  else
	  {
	    int index_cur = listSources.indexOf(mediaObjectForMetaInfos->currentSource());
	    qDebug()<<index_cur<<"\t"<<lastUpdated;
	    if(index_cur>=lastUpdated || index_cur==-1)
	    {
	      mediaObjectForMetaInfos->setCurrentSource(listSources.at(lastUpdated+1));
	    }
	  }
	}
  
}

void
Engine::refreshPlayedTime()
{
	currentTime->setText(Engine::msToString(mediaObject->currentTime()));
//	totalTime->setText(" / " + Engine::msToString(mediaObject->totalTime()));
	
}

Media
Engine::getInfos(unsigned int row)
{
	Media media;
	if (row < (unsigned int)listMedias.count())
	{
		media = listMedias.at(row);
	}
	return media;
}

QString
Engine::getUri(unsigned int row)
{
	QString ret = "";
	if (row < (unsigned int)listUris.count())
	{
		ret = listUris.at(row);
	}
	return ret;
}

void
Engine::metaInfosUpdated(Phonon::State newState, Phonon::State oldState)
{
	// When a file was added, and when
	// his metadata were resolved, we can add it to the displayed playlist
	
	 if (newState != Phonon::StoppedState && newState != Phonon::PausedState) //
	  return;
	 
	 if (mediaObjectForMetaInfos->currentSource().type() == Phonon::MediaSource::Invalid)
          return;
	
	 //mediaObjectForMetaInfos
	  QMap<QString, QString> metaData = mediaObjectForMetaInfos->metaData();

	Media media;
		// get infos
	media.title = metaData.value("TITLE");
	if (media.title == "")
	{
	  int nn=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
	  QFileInfo fi(listUris[nn]);
	  media.title = fi.fileName();
	}
	media.artist = metaData.value("ARTIST");
	media.album = metaData.value("ALBUM");
	media.totalTime = Engine::msToString(mediaObjectForMetaInfos->totalTime());
	
	QString result;
	if(media.artist == "")
	  result = media.title;
	else
	  result = media.artist + " - " + media.title;
	
	parent->ui->changeItem(result, listSources.indexOf(mediaObjectForMetaInfos->currentSource()));
	listMedias.replace(listSources.indexOf(mediaObjectForMetaInfos->currentSource()),media);
	//parent->ui->addItem(result);
	//listMedias.append(media);
	lastUpdated=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
	int index = listSources.indexOf(mediaObjectForMetaInfos->currentSource()) + 1;
	if (listSources.size() > index) 
	{
	  mediaObjectForMetaInfos->setCurrentSource(listSources.at(index));
	}

}

void Engine::currentInfosUpdated(Phonon::State newState, Phonon::State oldState)
{
   //qDebug()<<"=======>oldState: "<<oldState;
   //qDebug()<<"=======>newState: "<<newState;
  if (newState == Phonon::PlayingState )
  {
    totalTime->setText(" / " + Engine::msToString(mediaObject->totalTime()));
  
  
  //bool updateMetaOnPlay=true;
  
    if ((parent->config->useTags)&&(parent->config->updateOnPlay))
    {
      if (mediaObject->currentSource().type() != Phonon::MediaSource::Invalid)
      {
	  QMap<QString, QString> metaData = mediaObject->metaData();
	  Media media;
	
	  media.title = metaData.value("TITLE");
	  media.artist = metaData.value("ARTIST");
	  media.album = metaData.value("ALBUM");
	  media.totalTime = Engine::msToString(mediaObject->totalTime());
	
	  if(media.title!="")
	  {
	    QString result;
	    result = media.artist + " - " + media.title;
	    parent->ui->changeItem(result, currentPlayedMedia);
	    listMedias.replace(currentPlayedMedia,media);
	    //qDebug()<<currentPlayedMedia;
	    //qDebug()<<listSources.indexOf(mediaObject->currentSource());
	  
	  }
      }        
    }
  
  
    // Get infos
    Media media = getInfos(currentPlayedMedia);

    QString s;

    if (media.artist.isEmpty())
    {
      s = media.title + "\n";
      parent->ui->setWindowTitle(media.title);
    }
    else
    {
      s = media.artist + "\n" + media.title;
      parent->ui->setWindowTitle(media.artist+" - "+ media.title);
    }

    parent->ui->setInfos(s);
    
  }
  
  
  //mediaObject
  
}

void
Engine::playEnded()
{
	parent->next();
}

int
Engine::delMedia(int row)
{
	int ret = 0;
	if (row < listMedias.count())
	{
		listMedias.remove(row);
		listSources.remove(row);
		listUris.remove(row);
		ret = 1;
		if(lastUpdated>listMedias.count()-1)
		  lastUpdated=listMedias.count()-1;
	}
	return ret;
}

void
Engine::clearPlayList()
{
	if (parent && parent->ui)
		parent->ui->clearPlaylist();
	listMedias.clear();
	listSources.clear();
	listUris.clear();
	lastUpdated=-1;
}

QString
Engine::msToString(qint64 ms)
{
	QString ret = "";
	qint64 tmp = ms / 1000;
	int seconds = 0;
	int minutes = 0;
	int hours = 0;
	int tmpMins = tmp/60;
	if (tmpMins > 59)
	{
		hours = tmpMins/60;
		minutes = tmpMins%60;		
	}
	else
	{
		minutes = tmpMins;
	}
	seconds = tmp%60;

	if (hours > 0)
	{ // with hours
		/**
		 * We test if minutes/10 == 0 
		 * to not have a display like this -> 1:5:12
		 * but a display like this -> 1:05:12
		 */
		ret += QString::number(hours) + ":";
		if (minutes/10 == 0)
		{
			ret += "0";
		}
		ret += QString::number(minutes) + ":";
		if (seconds/10 == 0)
		{
			ret += "0";
		}
		ret += QString::number(seconds);
	}
	else
	{ // without hours
		ret += QString::number(minutes) + ":";
		if (seconds/10 == 0)
		{
			ret += "0";
		}
		ret += QString::number(seconds);
	}
	return ret;
}
